aboutsummaryrefslogtreecommitdiff
path: root/delegate/src/Slice.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'delegate/src/Slice.hpp')
-rw-r--r--delegate/src/Slice.hpp49
1 files changed, 17 insertions, 32 deletions
diff --git a/delegate/src/Slice.hpp b/delegate/src/Slice.hpp
index 6e355ae741..cbcb45ec65 100644
--- a/delegate/src/Slice.hpp
+++ b/delegate/src/Slice.hpp
@@ -1,5 +1,5 @@
//
-// Copyright © 2020 Arm Ltd and Contributors. All rights reserved.
+// Copyright © 2022 Arm Ltd and Contributors. All rights reserved.
// SPDX-License-Identifier: MIT
//
@@ -21,10 +21,10 @@ TfLiteStatus VisitSliceOperator(DelegateData& delegateData,
int nodeIndex,
int32_t sliceOperatorCode)
{
- TF_LITE_ENSURE_STATUS(ValidateNumInputs(tfLiteContext, tfLiteNode, 4, nodeIndex));
+ TF_LITE_ENSURE_STATUS(ValidateNumInputs(tfLiteContext, tfLiteNode, 3, nodeIndex));
TF_LITE_ENSURE_STATUS(ValidateNumOutputs(tfLiteContext, tfLiteNode, 1, nodeIndex));
// Read inputs [input, begin, end, strides]
int numInputs = tfLiteNode->inputs->size;
std::vector<const TfLiteTensor*> tfLiteInputs;
tfLiteInputs.reserve(numInputs);
@@ -39,15 +39,15 @@ TfLiteStatus VisitSliceOperator(DelegateData& delegateData,
}
}
// We save the begin, end and strides tensors in our descriptor. Therefore we have to read those values from inputs
int inputRank = tfLiteInputs[0]->dims->size;
- auto ReadInt32Input = [&](int inputIndex, std::vector<int32_t>& outputData) -> TfLiteStatus
+ auto ReadInt32Input = [&](int inputIndex, std::vector<uint32_t>& outputData) -> TfLiteStatus
{
if (tfLiteInputs[inputIndex]->type != kTfLiteInt32)
{
TF_LITE_MAYBE_KERNEL_LOG(
tfLiteContext,
- "TfLiteArmnnDelegate: The Begin-, End- and Stride-Tensors of the StridedSlice operation need to "
+ "TfLiteArmnnDelegate: The Begin- and Size-Tensors of the Slice operation need to "
"be of type int32. Operator: #%d node #%d: ",
sliceOperatorCode, nodeIndex);
return kTfLiteError;
@@ -57,7 +57,7 @@ TfLiteStatus VisitSliceOperator(DelegateData& delegateData,
{
TF_LITE_MAYBE_KERNEL_LOG(
tfLiteContext,
- "TfLiteArmnnDelegate: The Begin-, End- and Stride-Tensors of the StridedSlice operation need to "
+ "TfLiteArmnnDelegate: The Begin- and Size-Tensors of the Slice operation need to "
"be a 1D-Tensor. Operator: #%d node #%d: ",
sliceOperatorCode, nodeIndex);
return kTfLiteError;
@@ -67,41 +67,26 @@ TfLiteStatus VisitSliceOperator(DelegateData& delegateData,
{
TF_LITE_MAYBE_KERNEL_LOG(
tfLiteContext,
- "TfLiteArmnnDelegate: The number of values in the Begin-, End- and Stride-Tensors of the "
- "StridedSlice operation need to be equal to the rank of the Input-Tensor. Operator: #%d node #%d: ",
+ "TfLiteArmnnDelegate: The number of values in the Begin- and Size-Tensors of the "
+ "Slice operation need to be equal to the rank of the Input-Tensor. Operator: #%d node #%d: ",
sliceOperatorCode, nodeIndex);
return kTfLiteError;
}
// return tensor data
- auto* tensorDataPtr = tflite::GetTensorData<int32_t>(tfLiteInputs[inputIndex]);
+ auto* tensorDataPtr = tflite::GetTensorData<uint32_t>(tfLiteInputs[inputIndex]);
outputData.assign(tensorDataPtr, tensorDataPtr+numValues);
return kTfLiteOk;
};
- std::vector<int32_t> beginData;
- if (ReadInt32Input(1, beginData) != kTfLiteOk)
+ std::vector<uint32_t> begin;
+ if (ReadInt32Input(1, begin) != kTfLiteOk)
return kTfLiteError;
- std::vector<int32_t> endData;
- if (ReadInt32Input(2, endData) != kTfLiteOk)
+ std::vector<uint32_t> size;
+ if (ReadInt32Input(2, size) != kTfLiteOk)
return kTfLiteError;
- std::vector<int32_t> strideData;
- if (ReadInt32Input(3, strideData) != kTfLiteOk)
- return kTfLiteError;
-
- // parse built in options
- auto* stridedSliceParams = reinterpret_cast<TfLiteStridedSliceParams*>(tfLiteNode->builtin_data);
// Write all data to the descriptor
- armnn::StridedSliceDescriptor descriptor;
- descriptor.m_Begin = std::move(beginData);
- descriptor.m_End = std::move(endData);
- descriptor.m_Stride = std::move(strideData);
- descriptor.m_BeginMask = stridedSliceParams->begin_mask;
- descriptor.m_EllipsisMask = stridedSliceParams->ellipsis_mask;
- descriptor.m_EndMask = stridedSliceParams->end_mask;
- descriptor.m_NewAxisMask = stridedSliceParams->new_axis_mask;
- descriptor.m_ShrinkAxisMask = stridedSliceParams->shrink_axis_mask;
- descriptor.m_DataLayout = armnn::DataLayout::NHWC;
+ armnn::SliceDescriptor descriptor(begin, size);
// Validate output
const TfLiteTensor& tfLiteOutputTensor = tfLiteTensors[tfLiteNode->outputs->data[0]];
@@ -118,7 +103,7 @@ TfLiteStatus VisitSliceOperator(DelegateData& delegateData,
{
FORWARD_LAYER_SUPPORT_FUNC("SLICE",
tfLiteContext,
- IsStridedSliceSupported,
+ IsSliceSupported,
delegateData.m_Backends,
isSupported,
inputTensorInfo,
@@ -133,7 +118,7 @@ TfLiteStatus VisitSliceOperator(DelegateData& delegateData,
}
// Add a StridedSlice layer
- armnn::IConnectableLayer* layer = delegateData.m_Network->AddStridedSliceLayer(descriptor);
+ armnn::IConnectableLayer* layer = delegateData.m_Network->AddSliceLayer(descriptor);
ARMNN_ASSERT(layer != nullptr);
armnn::IOutputSlot& outputSlot = layer->GetOutputSlot(0);
@@ -21,10 +21,10 @@ TfLiteStatus VisitSliceOperator(DelegateData& delegateData,
TF_LITE_ENSURE_STATUS(ValidateNumOutputs(tfLiteContext, tfLiteNode, 1, nodeIndex));
- // Read inputs [input, begin, end, strides]
+ // Read inputs [input, begin, size]
int numInputs = tfLiteNode->inputs->size;
std::vector<const TfLiteTensor*> tfLiteInputs;
@@ -39,15 +39,15 @@ TfLiteStatus VisitSliceOperator(DelegateData& delegateData,
}
}
- // We save the begin, end and strides tensors in our descriptor. Therefore we have to read those values from inputs
+ // We save the begin and size tensors in our descriptor. Therefore we have to read those values from inputs
int inputRank = tfLiteInputs[0]->dims->size;